API Reference
=============

This section contains the complete API reference for lcvtoolbox, automatically generated from the source code.

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:

   lcvtoolbox

Package Structure
-----------------

Core Modules
~~~~~~~~~~~~

.. autosummary::
   :toctree: _autosummary
   :recursive:

   lcvtoolbox.core
   lcvtoolbox.core.schemas
   lcvtoolbox.core.utils

Vision Modules
~~~~~~~~~~~~~~

.. autosummary::
   :toctree: _autosummary
   :recursive:

   lcvtoolbox.vision
   lcvtoolbox.vision.camera
   lcvtoolbox.vision.encoding
   lcvtoolbox.vision.geometry
   lcvtoolbox.vision.image

Data Modules
~~~~~~~~~~~~

.. autosummary::
   :toctree: _autosummary
   :recursive:

   lcvtoolbox.data
   lcvtoolbox.data.generators
   lcvtoolbox.data.metadata

Integration Modules
~~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: _autosummary
   :recursive:

   lcvtoolbox.integrations
   lcvtoolbox.integrations.cvat
   lcvtoolbox.integrations.huggingface

CLI Module
~~~~~~~~~~

.. autosummary::
   :toctree: _autosummary
   :recursive:

   lcvtoolbox.cli
